==> libreoffice-fresh-sdk-7.6.3-2-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/typedefs_10.js <==
var searchData=
[
  ['segments_0',['Segments',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapePath.html#aa917ae921f3e9900710d222e91f60a3e',1,'com::sun::star::drawing::EnhancedCustomShapePath']]],
  ['selectedcolumnindexes_1',['SelectedColumnIndexes',['../structcom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridSelectionEvent.html#ad91d76c7e27f575afd5c5f8bce3426ed',1,'com::sun::star::awt::grid::GridSelectionEvent']]],
  ['selecteditems_2',['SelectedItems',['../servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlListBoxModel.html#a07821dac2ae824b9eeaf2fb5ee5fce46',1,'com::sun::star::awt::UnoControlListBoxModel']]],
  ['selectedrowindexes_3',['SelectedRowIndexes',['../structcom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridSelectionEvent.html#a966f81dd91f1d9c25cfd95d46cbb2546',1,'com::sun::star::awt::grid::GridSelectionEvent']]],
  ['selectedvalues_4',['SelectedValues',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseListBox.html#a42bdf5f2c50db2116460a7425cacf207',1,'com::sun::star::form::component::DatabaseListBox']]],
  ['selection_5',['selection',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DataAccessDescriptor.html#a42f93ea78e286c0f30c2ddf14e1b0cb6',1,'com::sun::star::sdb::DataAccessDescriptor::Selection'],['../servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a42f93ea78e286c0f30c2ddf14e1b0cb6',1,'com::sun::star::text::MailMerge::Selection']]],
  ['sequencemapping_6',['SequenceMapping',['../servicecom_1_1sun_1_1star_1_1chart2_1_1data_1_1TabularDataProviderArguments.html#afdb2fbfd71c86e244258a9eec06b971f',1,'com::sun::star::chart2::data::TabularDataProviderArguments']]],
  ['serialnumber_7',['SerialNumber',['../interfacecom_1_1sun_1_1star_1_1security_1_1XCertificate.html#a1a9cdc6a2cf340d3d322e6a05b79e7cc',1,'com::sun::star::security::XCertificate']]],
  ['seriesaddresses_8',['SeriesAddresses',['../servicecom_1_1sun_1_1star_1_1chart_1_1ChartTableAddressSupplier.html#a8ad1af90a74818adbb3eb87acb50c574',1,'com::sun::star::chart::ChartTableAddressSupplier']]],
  ['servicearguments_9',['ServiceArguments',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a3d06cfe5200379fa4e4747d8a121995a',1,'com::sun::star::sheet::DataPilotDescriptor']]],
  ['sha1thumbprint_10',['SHA1Thumbprint',['../interfacecom_1_1sun_1_1star_1_1security_1_1XCertificate.html#a43c0fdfde95a7c517c306b8c1417c732',1,'com::sun::star::security::XCertificate']]],
  ['solution_11',['Solution',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSolver.html#a7270bda2ff2bc01db8fa245d74d1d380',1,'com::sun::star::sheet::XSolver']]],
  ['sortfields_12',['sortfields',['../servicecom_1_1sun_1_1star_1_1table_1_1TableSortDescriptor.html#a29201edb2b9143cc355d0536935273ab',1,'com::sun::star::table::TableSortDescriptor::SortFields'],['../servicecom_1_1sun_1_1star_1_1table_1_1TableSortDescriptor2.html#a116f435f37daff0cdb988c5a8f44a2eb',1,'com::sun::star::table::TableSortDescriptor2::SortFields']]],
  ['sortinginfo_13',['SortingInfo',['../structcom_1_1sun_1_1star_1_1ucb_1_1OpenCommandArgument2.html#a94801fb6c7066f50463a41fa0b8d4179',1,'com::sun::star::ucb::OpenCommandArgument2']]],
  ['sortkeys_14',['SortKeys',['../servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1Bibliography.html#a5545006bc7c81d457c522305d4820627',1,'com::sun::star::text::fieldmaster::Bibliography']]],
  ['startoffset_15',['startOffset',['../structcom_1_1sun_1_1star_1_1util_1_1SearchResult.html#a376c183343c0995ac0df8da230e7c74a',1,'com::sun::star::util::SearchResult']]],
  ['stringitemlist_16',['stringitemlist',['../servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlComboBoxModel.html#ab67dde588dfb471f34a63e08de319451',1,'com::sun::star::awt::UnoControlComboBoxModel::StringItemList'],['../servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlListBoxModel.html#ab67dde588dfb471f34a63e08de319451',1,'com::sun::star::awt::UnoControlListBoxModel::StringItemList']]],
  ['styleinteropgrabbag_17',['StyleInteropGrabBag',['../servicecom_1_1sun_1_1star_1_1style_1_1Style.html#a5a02ab00318c00b25b9520782e430e3b',1,'com::sun::star::style::Style']]],
  ['subcomponents_18',['SubComponents',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XDatabaseDocumentUI.html#a4c2fc2f963c27e660f77a5bc106595e7',1,'com::sun::star::sdb::application::XDatabaseDocumentUI']]],
  ['subincrements_19',['SubIncrements',['../structcom_1_1sun_1_1star_1_1chart2_1_1IncrementData.html#a47e7a6a2ed44449026163890979a40b8',1,'com::sun::star::chart2::IncrementData']]],
  ['subjectpublickeyvalue_20',['SubjectPublicKeyValue',['../interfacecom_1_1sun_1_1star_1_1security_1_1XCertificate.html#a28fb893affae417171eef160a02e7682',1,'com::sun::star::security::XCertificate']]],
  ['subjectuniqueid_21',['SubjectUniqueID',['../interfacecom_1_1sun_1_1star_1_1security_1_1XCertificate.html#a89910e0485d3b953a3b59aa5f22fb47c',1,'com::sun::star::security::XCertificate']]],
  ['subtotals_22',['subtotals',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceLevel.html#ab375ddb9e630c396ce781b7b7d099c3a',1,'com::sun::star::sheet::DataPilotSourceLevel::SubTotals'],['../servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotField.html#aad9615897f61f0f2e845247d021763c3',1,'com::sun::star::sheet::DataPilotField::Subtotals']]],
  ['subtotals2_23',['subtotals2',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceLevel.html#acc7c3eda1e24c3608efd8bce102829de',1,'com::sun::star::sheet::DataPilotSourceLevel::SubTotals2'],['../servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotField.html#a3faedfa5a2e0fa107bf142c11418a80c',1,'com::sun::star::sheet::DataPilotField::Subtotals2']]],
  ['subviewsize_24',['SubViewSize',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapePath.html#abdce1cd47ba47d815f2eee32521a4d6d',1,'com::sun::star::drawing::EnhancedCustomShapePath']]],
  ['supporteddataflavors_25',['SupportedDataFlavors',['../structcom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1DropTargetDragEnterEvent.html#a0951887f297265c2d576330bb7214abd',1,'com::sun::star::datatransfer::dnd::DropTargetDragEnterEvent']]],
  ['systemproperties_26',['SystemProperties',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1JDBCConnectionProperties.html#a1d6ef2db02ea4535d87d34ba58249463',1,'com::sun::star::sdbc::JDBCConnectionProperties']]]
];

==> libreoffice-fresh-sdk-24.2.0-2-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/typedefs_10.js <==
var searchData=
[
  ['segments_0',['Segments',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapePath.html#aa917ae921f3e9900710d222e91f60a3e',1,'com::sun::star::drawing::EnhancedCustomShapePath']]],
  ['selectedcolumnindexes_1',['SelectedColumnIndexes',['../structcom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridSelectionEvent.html#ad91d76c7e27f575afd5c5f8bce3426ed',1,'com::sun::star::awt::grid::GridSelectionEvent']]],
  ['selecteditems_2',['SelectedItems',['../servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlListBoxModel.html#a07821dac2ae824b9eeaf2fb5ee5fce46',1,'com::sun::star::awt::UnoControlListBoxModel']]],
  ['selectedrowindexes_3',['SelectedRowIndexes',['../structcom_1_1sun_1_1star_1_1awt_1_1grid_1_1GridSelectionEvent.html#a966f81dd91f1d9c25cfd95d46cbb2546',1,'com::sun::star::awt::grid::GridSelectionEvent']]],
  ['selectedvalues_4',['SelectedValues',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseListBox.html#a42bdf5f2c50db2116460a7425cacf207',1,'com::sun::star::form::component::DatabaseListBox']]],
  ['selection_5',['Selection',['../servicecom_1_1sun_1_1star_1_1sdb_1_1DataAccessDescriptor.html#a42f93ea78e286c0f30c2ddf14e1b0cb6',1,'com::sun::star::sdb::DataAccessDescriptor::Selection'],['../servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html#a42f93ea78e286c0f30c2ddf14e1b0cb6',1,'com::sun::star::text::MailMerge::Selection']]],
  ['sequencemapping_6',['SequenceMapping',['../servicecom_1_1sun_1_1star_1_1chart2_1_1data_1_1TabularDataProviderArguments.html#afdb2fbfd71c86e244258a9eec06b971f',1,'com::sun::star::chart2::data::TabularDataProviderArguments']]],
  ['serialnumber_7',['SerialNumber',['../interfacecom_1_1sun_1_1star_1_1security_1_1XCertificate.html#a1a9cdc6a2cf340d3d322e6a05b79e7cc',1,'com::sun::star::security::XCertificate']]],
  ['seriesaddresses_8',['SeriesAddresses',['../servicecom_1_1sun_1_1star_1_1chart_1_1ChartTableAddressSupplier.html#a8ad1af90a74818adbb3eb87acb50c574',1,'com::sun::star::chart::ChartTableAddressSupplier']]],
  ['servicearguments_9',['ServiceArguments',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html#a3d06cfe5200379fa4e4747d8a121995a',1,'com::sun::star::sheet::DataPilotDescriptor']]],
  ['sha1thumbprint_10',['SHA1Thumbprint',['../interfacecom_1_1sun_1_1star_1_1security_1_1XCertificate.html#a43c0fdfde95a7c517c306b8c1417c732',1,'com::sun::star::security::XCertificate']]],
  ['solution_11',['Solution',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSolver.html#a7270bda2ff2bc01db8fa245d74d1d380',1,'com::sun::star::sheet::XSolver']]],
  ['sortfields_12',['SortFields',['../servicecom_1_1sun_1_1star_1_1table_1_1TableSortDescriptor.html#a29201edb2b9143cc355d0536935273ab',1,'com::sun::star::table::TableSortDescriptor::SortFields'],['../servicecom_1_1sun_1_1star_1_1table_1_1TableSortDescriptor2.html#a116f435f37daff0cdb988c5a8f44a2eb',1,'com::sun::star::table::TableSortDescriptor2::SortFields']]],
  ['sortinginfo_13',['SortingInfo',['../structcom_1_1sun_1_1star_1_1ucb_1_1OpenCommandArgument2.html#a94801fb6c7066f50463a41fa0b8d4179',1,'com::sun::star::ucb::OpenCommandArgument2']]],
  ['sortkeys_14',['SortKeys',['../servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1Bibliography.html#a5545006bc7c81d457c522305d4820627',1,'com::sun::star::text::fieldmaster::Bibliography']]],
  ['startoffset_15',['startOffset',['../structcom_1_1sun_1_1star_1_1util_1_1SearchResult.html#a376c183343c0995ac0df8da230e7c74a',1,'com::sun::star::util::SearchResult']]],
  ['stringitemlist_16',['StringItemList',['../servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlComboBoxModel.html#ab67dde588dfb471f34a63e08de319451',1,'com::sun::star::awt::UnoControlComboBoxModel::StringItemList'],['../servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlListBoxModel.html#ab67dde588dfb471f34a63e08de319451',1,'com::sun::star::awt::UnoControlListBoxModel::StringItemList']]],
  ['styleinteropgrabbag_17',['StyleInteropGrabBag',['../servicecom_1_1sun_1_1star_1_1style_1_1Style.html#a5a02ab00318c00b25b9520782e430e3b',1,'com::sun::star::style::Style']]],
  ['subcomponents_18',['SubComponents',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XDatabaseDocumentUI.html#a4c2fc2f963c27e660f77a5bc106595e7',1,'com::sun::star::sdb::application::XDatabaseDocumentUI']]],
  ['subincrements_19',['SubIncrements',['../structcom_1_1sun_1_1star_1_1chart2_1_1IncrementData.html#a47e7a6a2ed44449026163890979a40b8',1,'com::sun::star::chart2::IncrementData']]],
  ['subjectpublickeyvalue_20',['SubjectPublicKeyValue',['../interfacecom_1_1sun_1_1star_1_1security_1_1XCertificate.html#a28fb893affae417171eef160a02e7682',1,'com::sun::star::security::XCertificate']]],
  ['subjectuniqueid_21',['SubjectUniqueID',['../interfacecom_1_1sun_1_1star_1_1security_1_1XCertificate.html#a89910e0485d3b953a3b59aa5f22fb47c',1,'com::sun::star::security::XCertificate']]],
  ['subtotals_22',['Subtotals',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotField.html#aad9615897f61f0f2e845247d021763c3',1,'com::sun::star::sheet::DataPilotField']]],
  ['subtotals_23',['SubTotals',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceLevel.html#ab375ddb9e630c396ce781b7b7d099c3a',1,'com::sun::star::sheet::DataPilotSourceLevel']]],
  ['subtotals2_24',['SubTotals2',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceLevel.html#acc7c3eda1e24c3608efd8bce102829de',1,'com::sun::star::sheet::DataPilotSourceLevel']]],
  ['subtotals2_25',['Subtotals2',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotField.html#a3faedfa5a2e0fa107bf142c11418a80c',1,'com::sun::star::sheet::DataPilotField']]],
  ['subviewsize_26',['SubViewSize',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapePath.html#abdce1cd47ba47d815f2eee32521a4d6d',1,'com::sun::star::drawing::EnhancedCustomShapePath']]],
  ['supporteddataflavors_27',['SupportedDataFlavors',['../structcom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1DropTargetDragEnterEvent.html#a0951887f297265c2d576330bb7214abd',1,'com::sun::star::datatransfer::dnd::DropTargetDragEnterEvent']]],
  ['systemproperties_28',['SystemProperties',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1JDBCConnectionProperties.html#a1d6ef2db02ea4535d87d34ba58249463',1,'com::sun::star::sdbc::JDBCConnectionProperties']]]
];
